==> add-content-workflow-angularjs-1.0.11.tgz: package/source/app/add-content-workflow.service.ts <==
import * as angular from 'angular';
import AddContentWorkflowCore from '@meltwater/add-content-workflow-core';

class AddContentWorkflowService {
    /*@ngInject*/
    constructor(
        private $mdDialog
    ) {
    }

    openWorkflow = (event, config) => {
        if(config.preSelectedTags === undefined || config.preSelectedTags === null) {
            config.preSelectedTags = [];
        }

        return this.$mdDialog.show({
            template: `<md-dialog class="mw-mini-modal mw-mini-modal--wide" aria-label="" layout="column">
                          <add-content-dialog class="mw-mini-modal-wrapper" workflow="$ctrl.workflow" layout="column"></add-content-dialog>
                       </md-dialog>`,
            parent: angular.element(document.body),
            targetEvent: event,
            controller: AddContentDialogController,
            controllerAs: '$ctrl',
            bindToController: true,
            locals: config
        })
    }

    openContentStatusDialog = (event, config) => {
        return this.$mdDialog.show({
            template: `<md-dialog class="mw-mini-modal mw-mini-modal--wide" aria-label="" layout="column">
                          <content-status-dialog class="mw-mini-modal-wrapper" workflow="$ctrl.workflow" layout="column"></content-status-dialog>
                       </md-dialog>`,
            parent: angular.element(document.body),
            targetEvent: event,
            controller: ContentStatusDialogController,
            controllerAs: '$ctrl',
            bindToController: true,
            locals: config
        })
    }
}

class AddContentDialogController {
    workflow: AddContentWorkflowCore.Workflow;
    /*@ngInject*/
    constructor(
        private AddContentService,
        private ContentRestrictionService,
        private DocumentService,
        private OpenGraphService,
        private $mdDialog,
        private AddContentTranslate,
        private userObject,
        private preSelectedTags
    ) {
        AddContentTranslate.use(this.userObject && this.userObject.language || 'en');

        this.workflow = new AddContentWorkflowCore.Workflow({
            saveAddContent: this.AddContentService.saveAddContent,
            getContentRestrictions: this.ContentRestrictionService.getRestrictions,
            closeWorkflow: this.$mdDialog.hide,
            getExistingDocuments: this.DocumentService.getExistingDocuments,
            scrapeUrls: this.OpenGraphService.scrapeUrls,
            getLegalAgreement: this.AddContentService.getLegalAgreement,
            saveLegalAgreement: this.AddContentService.saveLegalAgreement,
            userObject: this.userObject,
            preSelectedTags: this.preSelectedTags || []
        });
    }
}

class ContentStatusDialogController {
    workflow: any = {};
    constructor(
        private AddContentTranslate,
        private documents,
        private userObject
    ) {
        this.workflow.processingDocuments = [];
        this.workflow.completedDocuments = [];
        this.workflow.contentStatusError = false;

        AddContentTranslate.use(this.userObject && this.userObject.language || 'en');

        this.documents.forEach(document => {
            if (document.contentIndexed) {
                this.workflow.completedDocuments.push(document);
            } else {
                this.workflow.processingDocuments.push(document);
            }
        })
    }
}

export default AddContentWorkflowService;

==> add-content-workflow-angularjs-1.1.9.tgz: package/source/app/add-content-workflow.service.ts <==
import * as angular from 'angular';
import AddContentWorkflowCore from '@meltwater/add-content-workflow-core';

class AddContentWorkflowService {
    /*@ngInject*/
    constructor(
        private AddContentService,
        private $mdDialog,
        private $q
    ) {
    }

    openWorkflow = (event, config) => {
        let {_id, activeCompanyId } = config.userObject
        if(config.preSelectedTags === undefined || config.preSelectedTags === null) {
            config.preSelectedTags = [];
        }
        return this.$q((resolve,reject)=>{
            this.AddContentService.getLegalAgreement(activeCompanyId, _id)
                .then((legalAgreement)=>{
                    config.userHasLegalAgreement = !!legalAgreement
                    resolve( this.$mdDialog.show({
                        template: `<md-dialog class="mw-mini-modal mw-mini-modal--wide" aria-label="" layout="column">
                                    <add-content-dialog class="mw-mini-modal-wrapper" workflow="$ctrl.workflow" layout="column"></add-content-dialog>
                                </md-dialog>`,
                        parent: angular.element(document.body),
                        targetEvent: event,
                        controller: AddContentDialogController,
                        controllerAs: '$ctrl',
                        bindToController: true,
                        locals: config,
                    }))
                })
                .catch((err)=>{
                    reject(err)
                })
        })
    }

    openContentStatusDialog = (event, config) => {
        return this.$mdDialog.show({
            template: `<md-dialog class="mw-mini-modal mw-mini-modal--wide" aria-label="" layout="column">
                          <content-status-dialog class="mw-mini-modal-wrapper" workflow="$ctrl.workflow" layout="column"></content-status-dialog>
                       </md-dialog>`,
            parent: angular.element(document.body),
            targetEvent: event,
            controller: ContentStatusDialogController,
            controllerAs: '$ctrl',
            bindToController: true,
            locals: config
        })
    }
}

class AddContentDialogController {
    workflow: AddContentWorkflowCore.Workflow;
    /*@ngInject*/
    constructor(
        private AddContentService,
        private ContentRestrictionService,
        private DocumentService,
        private OpenGraphService,
        private $mdDialog,
        private AddContentTranslate,
        private userObject,
        private preSelectedTags,
        private userHasLegalAgreement,
        private AvailableContentService,
    ) {
        AddContentTranslate.use(this.userObject && this.userObject.language || 'en');

        this.workflow = new AddContentWorkflowCore.Workflow({
            saveAddContent: this.AddContentService.saveAddContent,
            getContentRestrictions: this.ContentRestrictionService.getRestrictions,
            closeWorkflow: this.$mdDialog.hide,
            getLegalAgreement: this.AddContentService.getLegalAgreement,
            saveLegalAgreement: this.AddContentService.saveLegalAgreement,
            userObject: this.userObject,
            preSelectedTags: this.preSelectedTags || [],
            userHasLegalAgreement: this.userHasLegalAgreement,
            getAvailableContent: this.AvailableContentService.getAvailableContent
        });
    }
}

class ContentStatusDialogController {
    workflow: any = {};
    constructor(
        private AddContentTranslate,
        private documents,
        private userObject
    ) {
        this.workflow.processingDocuments = [];
        this.workflow.completedDocuments = [];
        this.workflow.contentStatusError = false;

        AddContentTranslate.use(this.userObject && this.userObject.language || 'en');

        this.documents.forEach(document => {
            if (document.contentIndexed) {
                this.workflow.completedDocuments.push(document);
            } else {
                this.workflow.processingDocuments.push(document);
            }
        })
    }
}

export default AddContentWorkflowService;
